@@ -1,41 +1,29 @@
 /*
- * Copyright © 2018 Red Hat, Inc
+ * SPDX-FileCopyrightText: 2018 Red Hat Inc
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library. If not, see <http://www.gnu.org/licenses/>.
- *
- * Authors:
- *       Jan Grulich <jgrulich@redhat.com>
+ * SPDX-FileCopyrightText: 2018 Jan Grulich <jgrulich@redhat.com>
  */
 
 #include "screenshot.h"
 #include "screenshotdialog.h"
 #include "utils.h"
 
-#include <QDateTime>
-#include <QtDBus>
 #include <QDBusArgument>
 #include <QDBusReply>
+#include <QDateTime>
 #include <QLoggingCategory>
-#include <QStandardPaths>
 #include <QPointer>
+#include <QStandardPaths>
+#include <QtDBus>
 
 Q_LOGGING_CATEGORY(XdgDesktopPortalKdeScreenshot, "xdp-kde-screenshot")
 
 // Keep in sync with qflatpakcolordialog from Qt flatpak platform theme
 Q_DECLARE_METATYPE(ScreenshotPortal::ColorRGB)
 
-QDBusArgument &operator <<(QDBusArgument &arg, const ScreenshotPortal::ColorRGB &color)
+QDBusArgument &operator<<(QDBusArgument &arg, const ScreenshotPortal::ColorRGB &color)
 {
     arg.beginStructure();
     arg << color.red << color.green << color.blue;
@@ -43,7 +31,7 @@ QDBusArgument &operator <<(QDBusArgument &arg, const ScreenshotPortal::ColorRGB
     return arg;
 }
 
-const QDBusArgument &operator >>(const QDBusArgument &arg, ScreenshotPortal::ColorRGB &color)
+const QDBusArgument &operator>>(const QDBusArgument &arg, ScreenshotPortal::ColorRGB &color)
 {
     double red, green, blue;
     arg.beginStructure();
@@ -56,7 +44,7 @@ const QDBusArgument &operator >>(const QDBusArgument &arg, ScreenshotPortal::Col
     return arg;
 }
 
-QDBusArgument &operator<< (QDBusArgument &argument, const QColor &color)
+QDBusArgument &operator<<(QDBusArgument &argument, const QColor &color)
 {
     argument.beginStructure();
     argument << color.rgba();
@@ -105,10 +93,12 @@ uint ScreenshotPortal::Screenshot(const QDBusObjectPath &handle,
 
     const bool interactive = options.value(QStringLiteral("interactive"), false).toBool();
     if (!interactive) {
-        screenshotDialog->takeScreenshot();
+        screenshotDialog->takeScreenshotNonInteractive();
+    } else {
+        screenshotDialog->exec();
     }
 
-    QImage screenshot = screenshotDialog->exec() ? screenshotDialog->image() : QImage();
+    const QImage screenshot = screenshotDialog->image();
 
     if (screenshotDialog) {
         screenshotDialog->deleteLater();
@@ -118,8 +108,9 @@ uint ScreenshotPortal::Screenshot(const QDBusObjectPath &handle,
         return 1;
     }
 
-    const QString filename = QStringLiteral("%1/Screenshot_%2.png").arg(QStandardPaths::writableLocation(QStandardPaths::PicturesLocation),
-                                                                        QDateTime::currentDateTime().toString(QStringLiteral("yyyyMMdd_hhmmss")));
+    const QString filename =
+        QStringLiteral("%1/Screenshot_%2.png") //
+            .arg(QStandardPaths::writableLocation(QStandardPaths::PicturesLocation), QDateTime::currentDateTime().toString(QStringLiteral("yyyyMMdd_hhmmss")));
 
     if (!screenshot.save(filename, "PNG")) {
         return 1;
