@@ -1,28 +1,16 @@
 /*
- * Copyright © 2018 Red Hat, Inc
+ * SPDX-FileCopyrightText: 2018 Red Hat Inc
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library. If not, see <http://www.gnu.org/licenses/>.
- *
- * Authors:
- *       Jan Grulich <jgrulich@redhat.com>
+ * SPDX-FileCopyrightText: 2018 Jan Grulich <jgrulich@redhat.com>
  */
 
 #ifndef XDG_DESKTOP_PORTAL_KDE_SESSION_H
 #define XDG_DESKTOP_PORTAL_KDE_SESSION_H
 
-#include <QObject>
 #include <QDBusVirtualObject>
+#include <QObject>
 
 #include "remotedesktop.h"
 #include "screencast.h"
@@ -36,7 +24,7 @@ public:
 
     enum SessionType {
         ScreenCast = 0,
-        RemoteDesktop = 1
+        RemoteDesktop = 1,
     };
 
     bool handleMessage(const QDBusMessage &message, const QDBusConnection &connection) override;
@@ -69,7 +57,10 @@ public:
     bool multipleSources() const;
     ScreenCastPortal::SourceType types() const;
 
-    SessionType type() const override { return SessionType::ScreenCast; }
+    SessionType type() const override
+    {
+        return SessionType::ScreenCast;
+    }
 
 private:
     bool m_multipleSources;
@@ -90,7 +81,10 @@ public:
     bool screenSharingEnabled() const;
     void setScreenSharingEnabled(bool enabled);
 
-    SessionType type() const override { return SessionType::RemoteDesktop; }
+    SessionType type() const override
+    {
+        return SessionType::RemoteDesktop;
+    }
 
 private:
     bool m_screenSharingEnabled;
@@ -98,4 +92,3 @@ private:
 };
 
 #endif // XDG_DESKTOP_PORTAL_KDE_SESSION_H
-
